@@ -17,7 +17,7 @@ use Readonly;
 Readonly::Scalar our $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -69,6 +69,10 @@ sub run {
 		my (undef, undef, $suffix) = fileparse($self->{'_output_file'},
 			qr{\..*$});
 		$suffix =~ s/^\.//g;
+		my $type = lc($suffix);
+		if ($type eq 'jpg') {
+			$type = 'jpeg';
+		}
 
 		# Images from directory.
 		my $ig;
@@ -77,7 +81,7 @@ sub run {
 				'debug' => ($self->{'_opts'}->{'v'} ? 1 : 0),
 				'height' => $self->{'_height'},
 				'path_to_images' => $self->{'_opts'}->{'i'},
-				'type' => $suffix,
+				'type' => $type,
 				'width' => $self->{'_width'},
 			);
 
@@ -85,7 +89,7 @@ sub run {
 		} else {
 			$ig = Image::Random->new(
 				'height' => $self->{'_height'},
-				'type' => $suffix,
+				'type' => $type,
 				'width'=> $self->{'_width'},
 			);
 		}
@@ -194,11 +198,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015 Michal Špaček
+ © 2015-2016 Michal Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
